@@ -182,10 +182,10 @@ class Client:
 
             page_num = response.get("pages").get("current")
             next_page = response.get("links", {}).get("next")
-            log.info(f"Page {page_num} for {language} language.")
+            log.debug(f"Page {page_num} for {language} language.")
 
-        log.info(
-            f"There are no more pages. Total count is {count} translations with {params} parameters \n"
+        log.debug(
+            f"There are no more pages. Total count is {count} translations with {params.get('views')} views \n"
             f"for {language} language."
         )
 
@@ -204,7 +204,7 @@ class Client:
 
         record_id = self.cache.hget(_SNAKE_NAME_MAP, key)
         if not record_id:
-            log.warning(f"Key {key} could not be found.")
+            log.debug(f"Key {key} could not be found.")
             raise TranslationKeyNotFound(
                 f"No keys were found in REDIS hash map {_SNAKE_NAME_MAP} for key {key}"
             )
@@ -225,7 +225,7 @@ class Client:
             if not self.cache.exists(self.__hash([language, view]))
         ]
         if views and not self.cache.hget(_VIEWS_ID_MAP, record_id):
-            log.info(f"Caching views {views} for {language} language")
+            log.debug(f"Caching views {views} for {language} language")
             _ = self.filter(language, views=views)
 
         # NOTE: 2. Compute which occurrences need refreshing and refresh them and all associations.
@@ -238,7 +238,7 @@ class Client:
             if not self.cache.exists(self.__hash([language, occurrence]))
         ]
         if occurrences and not self.cache.hget(_OCCURRENCES_ID_MAP, record_id):
-            log.info(f"Caching occurrences {occurrences} for {language} language")
+            log.debug(f"Caching occurrences {occurrences} for {language} language")
             _ = self.filter(
                 language,
                 occurrences=occurrences,
@@ -254,7 +254,7 @@ class Client:
 
         record_id = self.cache.hget(_ID_NAME_MAP, key)
         if not record_id:
-            log.info(f"Key {key} could not be found.")
+            log.debug(f"Key {key} could not be found.")
             raise TranslationKeyNotFound(
                 f"No keys were found in REDIS hash map {_ID_NAME_MAP} for key {key}"
             )
@@ -275,7 +275,7 @@ class Client:
             if not self.cache.exists(self.__hash([language, view]))
         ]
         if views and not self.cache.hget(_VIEWS_ID_MAP, record_id):
-            log.info(f"Caching views {views} for {language} language")
+            log.debug(f"Caching views {views} for {language} language")
             _ = self.filter(language, views=views)
 
         # NOTE: 2. Compute which occurrences need refreshing and refresh them and all associations.
@@ -288,7 +288,7 @@ class Client:
             if not self.cache.exists(self.__hash([language, occurrence]))
         ]
         if occurrences and not self.cache.hget(_OCCURRENCES_ID_MAP, record_id):
-            log.info(f"Caching occurrences {occurrences} for {language} language")
+            log.debug(f"Caching occurrences {occurrences} for {language} language")
             _ = self.filter(
                 language,
                 occurrences=occurrences,
@@ -307,7 +307,10 @@ class Client:
         page_size: int = 500,
         page: int = 1,
     ):
-        """Filters translations by language, views and occurences."""
+        """
+        Filters translations by language, views and occurrences, and caches then in REDIS.
+        """
+
         if not language:
             raise django.urls.exceptions.NoReverseMatch("No language selected.")
 
@@ -432,15 +435,16 @@ class Client:
             )
 
         # 6. Cache new translations and assemble output.
-        log.info(f"Caching {len(translations)} translations...")
+        log.info(f"Caching {len(translations)} translations for {language} language...")
         result = {**result, **_cache_translations(translations)}
-        log.info(
-            f"Done. Cached {len(result.items())} items for {len(translations)} translations."
-        )
+        log.info(f"Done. Cached {len(result.items())} translation items.")
         return result
 
-    def get_bootstrap_keys(self, language, view) -> dict:
-        """Get translations keys from redis for bootstrap init call"""
+    def get_translation_keys(self, language, view) -> dict:
+        """
+        Get translation keys dictionary with snake_names and translations from REDIS for a provided language and view
+        """
+
         _SNAKE_NAME_MAP = f"{language}_snake_name"
         keys_dict = {}
 
@@ -457,6 +461,6 @@ class Client:
             keys = obj.get("key")
             views = keys.get("views") or []
             if view in views:
-                keys_dict[keys.get("snake_name")] = keys.get("id_name")
+                keys_dict[keys.get("snake_name")] = obj.get("translation")
 
         return keys_dict
